"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var recorder_exports = {};
__export(recorder_exports, {
  AudioRecorder: () => AudioRecorder
});
module.exports = __toCommonJS(recorder_exports);
class AudioRecorder {
  constructor(options = {}) {
    this.options = options;
  }
  context;
  listeners = {};
  buffer = [];
  recorder;
  stream;
  async start(deviceId) {
    this.recorder = await this.createAudioRecorder();
    this.recorder.start();
  }
  stop() {
    return new Promise((resolve) => {
      this.recorder?.addEventListener("stop", () => resolve(this.flush()));
      this.recorder?.stop();
      this.context?.suspend();
      this.stream?.getTracks().forEach((track) => track.stop());
    });
  }
  static listDevices() {
    return navigator.mediaDevices.enumerateDevices().then((list) => list.filter((d) => d.kind === "audioinput"));
  }
  on(eventName, callback) {
    if (!this.listeners[eventName]) {
      this.listeners[eventName] = [];
    }
    this.listeners[eventName]?.push(callback);
  }
  setStream(deviceId) {
    return navigator.mediaDevices.getUserMedia({
      audio: deviceId ? { deviceId } : true,
      video: false
    });
  }
  flush() {
    const blob = new Blob(this.buffer);
    this.buffer = [];
    return blob;
  }
  async createAudioRecorder() {
    const stream = await this.getAudioStream();
    const recorder = new MediaRecorder(stream, this.options);
    if ("volumechange" in this.listeners) {
      await this.setupAudioMeter();
    }
    recorder.addEventListener("dataavailable", (e) => {
      if (e.data.size > 0) {
        this.buffer?.push(e.data);
      }
    });
    return recorder;
  }
  fireEvent(name, event) {
    this.listeners[name]?.forEach((listener) => listener(event));
  }
  async getAudioStream() {
    if (!this.stream) {
      this.stream = await this.setStream();
    }
    return this.stream;
  }
  getAudioContext() {
    if (!this.context) {
      this.context = new AudioContext();
    }
    return this.context;
  }
  getWorkletPath(name) {
    return [this.options.workletPath ?? "worklets", "volume-meter.js"].join(
      "/"
    );
  }
  async setupAudioMeter() {
    const context = this.getAudioContext();
    const stream = await this.getAudioStream();
    await context.audioWorklet.addModule(this.getWorkletPath("video-meter.js"));
    const name = "volume-meter";
    const micNode = context.createMediaStreamSource(stream);
    const volumeMeterNode = new AudioWorkletNode(context, name);
    volumeMeterNode.port.onmessage = ({ data: volume }) => this.fireEvent("volumechange", { volume });
    micNode.connect(volumeMeterNode).connect(context.destination);
  }
}
//# sourceMappingURL=recorder.js.map
