"use strict";
const SMOOTHING_FACTOR = 0.8;
const FRAME_PER_SECOND = 60;
const FRAME_INTERVAL = 1 / FRAME_PER_SECOND;
class VolumeMeter extends AudioWorkletProcessor {
  lastUpdate = currentTime;
  volume = 0;
  calculateRMS(inputChannelData) {
    let sum = 0;
    for (let i = 0; i < inputChannelData.length; i++) {
      sum += inputChannelData[i] * inputChannelData[i];
    }
    let rms = Math.sqrt(sum / inputChannelData.length);
    this.volume = Math.max(rms, this.volume * SMOOTHING_FACTOR);
  }
  process(inputs, outputs) {
    const inputChannelData = inputs[0][0];
    if (currentTime - this.lastUpdate > FRAME_INTERVAL) {
      this.calculateRMS(inputChannelData);
      this.port.postMessage(this.volume);
      this.lastUpdate = currentTime;
    }
    return true;
  }
}
registerProcessor("volume-meter", VolumeMeter);
//# sourceMappingURL=volume-meter.js.map
