class AudioRecorder {
  constructor(options = {}) {
    this.options = options;
  }
  context;
  listeners = {};
  buffer = [];
  recorder;
  stream;
  async start(deviceId) {
    this.recorder = await this.createAudioRecorder();
    this.recorder.start();
  }
  stop() {
    return new Promise((resolve) => {
      this.recorder?.addEventListener("stop", () => resolve(this.flush()));
      this.recorder?.stop();
      this.context?.suspend();
      this.stream?.getTracks().forEach((track) => track.stop());
    });
  }
  static listDevices() {
    return navigator.mediaDevices.enumerateDevices().then((list) => list.filter((d) => d.kind === "audioinput"));
  }
  on(eventName, callback) {
    if (!this.listeners[eventName]) {
      this.listeners[eventName] = [];
    }
    this.listeners[eventName]?.push(callback);
  }
  setStream(deviceId) {
    return navigator.mediaDevices.getUserMedia({
      audio: deviceId ? { deviceId } : true,
      video: false
    });
  }
  flush() {
    const blob = new Blob(this.buffer);
    this.buffer = [];
    return blob;
  }
  async createAudioRecorder() {
    const stream = await this.getAudioStream();
    const recorder = new MediaRecorder(stream, this.options);
    if ("volumechange" in this.listeners) {
      await this.setupAudioMeter();
    }
    recorder.addEventListener("dataavailable", (e) => {
      if (e.data.size > 0) {
        this.buffer?.push(e.data);
      }
    });
    return recorder;
  }
  fireEvent(name, event) {
    this.listeners[name]?.forEach((listener) => listener(event));
  }
  async getAudioStream() {
    if (!this.stream) {
      this.stream = await this.setStream();
    }
    return this.stream;
  }
  getAudioContext() {
    if (!this.context) {
      this.context = new AudioContext();
    }
    return this.context;
  }
  getWorkletPath(name) {
    return [this.options.workletPath ?? "worklets", "volume-meter.js"].join(
      "/"
    );
  }
  async setupAudioMeter() {
    const context = this.getAudioContext();
    const stream = await this.getAudioStream();
    await context.audioWorklet.addModule(this.getWorkletPath("video-meter.js"));
    const name = "volume-meter";
    const micNode = context.createMediaStreamSource(stream);
    const volumeMeterNode = new AudioWorkletNode(context, name);
    volumeMeterNode.port.onmessage = ({ data: volume }) => this.fireEvent("volumechange", { volume });
    micNode.connect(volumeMeterNode).connect(context.destination);
  }
}
export {
  AudioRecorder
};
//# sourceMappingURL=recorder.js.map
