import type { AudioEventListener, AudioEventListenerMap, AudioRecorderOptions } from "./types";
export declare class AudioRecorder {
    private options;
    /**
     * The live audio context
     */
    private context?;
    /**
     * Dictionary of event listeners associated with the recorder
     */
    private listeners;
    /**
     * Buffer of currently recorded blob chunks
     */
    private buffer?;
    /**
     * Underlying media recorder object
     */
    private recorder?;
    /**
     * The currently active media stream
     */
    private stream?;
    constructor(options?: AudioRecorderOptions);
    /**
     * Starts recording audio using the given device ID or, if none is provided, the default device
     * @param deviceId Optional device ID to record with
     */
    start(deviceId?: string): Promise<void>;
    /**
     * Stops recording
     * @returns The recorded data as a Blob object
     */
    stop(): Promise<unknown>;
    /**
     * Lists all of the users available audio devices
     * @returns The list of Device objects
     */
    static listDevices(): Promise<MediaDeviceInfo[]>;
    /**
     * Attaches an event listener to the recorder
     * @param eventName The name of the event
     * @param callback The callback
     */
    on<T extends keyof AudioEventListenerMap>(eventName: T, callback: AudioEventListener<AudioEventListenerMap[T]>): void;
    /**
     * Gets a new audio stream using either the given device ID or the default device
     * if none is provided
     * @param deviceId An optional device ID
     * @returns The MediaStream object
     */
    setStream(deviceId?: string): Promise<MediaStream>;
    /**
     * Clears the currently recorded chunks and returns the existing
     * chunks as a single blob object
     * @returns The recorded chunks as a single
     */
    private flush;
    /**
     * Initializes a new audio recorder with the correct event listeners attached
     * @param stream The MediaStream object for which to create the recorder
     * @param options Recorder options
     * @returns
     */
    private createAudioRecorder;
    private fireEvent;
    private getAudioStream;
    private getAudioContext;
    private getWorkletPath;
    private setupAudioMeter;
}
